package go_swagger

import (
	"os"
	"path/filepath"

	"github.com/juju/errors"

	"git.home.m-and-m.ovh/mderasse/gouick/helpers"
	"git.home.m-and-m.ovh/mderasse/gouick/models"

	log "github.com/sirupsen/logrus"
)

type apiYamlTemplate struct {
	ProjectDescription string
	ProjectName        string
	ProjectContact     apiYamlContact
}

type apiYamlContact struct {
	Email string
	Name  string
	URL   string
}

// createDefaultAPIYamls will generate the main api yaml file based on the given config.
// Launched only at project init.
func (a APIType) createDefaultAPIYamls(path string, config *models.Config) error {
	log.Debugf("Starting %s - %s", a.GetName(), helpers.GetCurrentFuncName())

	type templateFileStruct struct {
		savePath     string
		templatePath string
	}

	templateFileList := []templateFileStruct{
		{
			savePath:     filepath.Join(path, "api.yaml"),
			templatePath: filepath.Join(templateDirectory, "api.yaml.tmpl"),
		},
		{
			savePath:     filepath.Join(path, "api/001-general.yaml"),
			templatePath: filepath.Join(templateDirectory, "api/001-general.yaml.tmpl"),
		},
		{
			savePath:     filepath.Join(path, "api/001-monitoring.yaml"),
			templatePath: filepath.Join(templateDirectory, "api/002-monitoring.yaml.tmpl"),
		},
	}

	data := apiYamlTemplate{
		ProjectDescription: config.ProjectDescription,
		ProjectName:        config.ProjectName,
		ProjectContact: apiYamlContact{
			Email: config.ProjectContact.Email,
			Name:  config.ProjectContact.Name,
			URL:   config.ProjectContact.URL,
		},
	}

	for _, templateFile := range templateFileList {

		err := helpers.WriteTemplate(templateFile.templatePath, templateFile.savePath, data)
		if err != nil {
			return errors.Trace(err)
		}
	}

	return nil
}

// deleteTempApiYaml will delete the temporary yaml api file generated by go-swagger.
func (a APIType) deleteTempApiYaml(path string) error {
	log.Debugf("Starting %s  - %s", a.GetName(), helpers.GetCurrentFuncName())

	tempFilePath := filepath.Join(path, mergeYamlFileName)

	// delete
	exist, err := helpers.FileExists(tempFilePath)
	if err != nil {
		return errors.Trace(err)
	}

	if !exist {
		log.Debug("File doesn't exist already")
		return nil
	}

	err = os.Remove(tempFilePath)
	if err != nil {
		log.Errorf("fail to delete file in %s", tempFilePath)
		return errors.Trace(err)
	}

	return nil
}
